@@ -29,7 +29,7 @@ public:
   typedef enum {ok=EXIT_SUCCESS, error=EXIT_FAILURE} exit_status;
 public:
   inline application():_curl(NULL) { }
-  inline virtual ~application()    { _close(); }
+  inline virtual ~application()    { }
 public:
   exit_status exec(int,char **);
 private:
